@@ -18,11 +18,11 @@
 import logging
 
 from keystoneauth1 import exceptions as ks_exc
+from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 
@@ -99,7 +99,7 @@ class CreateProject(command.ShowOne):
 
         # TODO(stevemar): Remove the line below when we support multitenancy
         project._info.pop('parent_id', None)
-        return zip(*sorted(six.iteritems(project._info)))
+        return zip(*sorted(project._info.items()))
 
 
 class DeleteProject(command.Command):
@@ -289,7 +289,7 @@ class ShowProject(command.ShowOne):
         # the API has and handle the extra top level properties.
         reserved = ('name', 'id', 'enabled', 'description')
         properties = {}
-        for k, v in info.items():
+        for k, v in list(info.items()):
             if k not in reserved:
                 # If a key is not in `reserved` it's a property, pop it
                 info.pop(k)
@@ -297,8 +297,8 @@ class ShowProject(command.ShowOne):
                 if v is not None:
                     properties[k] = v
 
-        info['properties'] = utils.format_dict(properties)
-        return zip(*sorted(six.iteritems(info)))
+        info['properties'] = format_columns.DictColumn(properties)
+        return zip(*sorted(info.items()))
 
 
 class UnsetProject(command.Command):
